/*

CGUIIrrObjectTreeViewer by Jonas Petersen a.k.a. "jox"

Version 0.1 - 19th March 2005 - Irrlicht 0.8

A GUI class that displays the hierarchy of all scene nodes and GUI elements present in the engine.

*/

#ifndef __C_GUI_IRR_OBJECT_TREE_VIEWER_H_INCLUDED__
#define __C_GUI_IRR_OBJECT_TREE_VIEWER_H_INCLUDED__

#include <irrlicht.h>

namespace irr {
namespace gui {

class CGUIIrrObjectTreeViewer : public IGUIElement
{
public:
	CGUIIrrObjectTreeViewer(IGUIEnvironment* environment, IGUIElement* parent, s32 id,
		core::rect<s32> rect, scene::ISceneManager* smgr, bool createWindow=true);

	~CGUIIrrObjectTreeViewer(void);
	
	//! Sets the with of the indentation in spaces
	void setIndentWidth(s32 width);

	//! If the viewer is created as a window the IGUIWindow will be returned, NULL is returned otherwise.
	IGUIWindow* getWindow();

	//! Reparses the scene nodes and updates the tree.
	void updateSceneNodes();

	//! Reparses the GUI elements and updates the tree.
	void updateGUIElements();

	bool OnEvent(SEvent event);

private:
	void parseGUIElements(gui::IGUIElement* parent, s32 level=0);
	void parseSceneNodes(scene::ISceneNode* node, s32 level=0);

	scene::ISceneManager* SceneManager;
	IGUIListBox* ListBox;
	s32 ObjCount;
	s32 IndentWidth;
	core::stringw IndentString;
	IGUIWindow* Window;
};

} // namespace irr
} // namespace gui 

#endif